/**
 * Configuration file for apeman projects.
 * @see https://github.com/apeman-labo/apeman
 */

'use strict'

module.exports = {
  /** Current working directory path */
  get $cwd () {
    return __dirname
  },
  /** Package data. */
  get $pkg () {
    return require('./package.json')
  },
  /** Prototype projects */
  get $proto () {
    return [
      require('apeman-proto-abstract'),
      require('apeman-proto-mysql'),
      require('apeman-proto-node'),
      require('apeman-proto-nginx')
    ]
  },
  /**
   * apeman tmpl configurations.
   * @see https://github.com/apeman-cmd-labo/apeman-tmpl
   */
  get $tmpls () {
    return {}
  },
  /**
   * apeman task configurations.
   * @see https://github.com/apeman-cmd-labo/apeman-task
   */
  get $tasks () {
    return {
      'lemn:mkdir': [
        'mysql:mkdir',
        'node:mkdir',
        'nginx:mkdir'
      ],
      'lemn:render': [
        'mysql:render',
        'node:render',
        'nginx:render'
      ],
      'lemn:chmod': [
        'mysql:chmod',
        'node:chmod',
        'nginx:chmod'
      ]
    }
  },
  /**
   * apeman infra configurations.
   * @see https://github.com/apeman-cmd-labo/apeman-infr
   */
  get $infrs () {
    return {
      mysql: './infr/mysql/Dockerfile',
      nginx: './infr/nginx/Dockerfile',
      node: './infr/node/Dockerfile'
    }
  },
  /**
   * apeman watch configurations.
   * @see https://github.com/apeman-cmd-labo/apeman-wtch
   */
  get $wtchs () {
    return {}
  },
  /** Note about properties. */
  get $notes () {
    return {
      '$tasks.lemn:mkdir': 'Make directories for NGINX, MySQL, Node.js',
      '$tasks.lemn:render': 'Render bud files for NGINX, MySQL, Node.js',
      '$tasks.lemn:chmod': 'Change permissions for NGINX, MySQL, Node.js'
    }
  },
  /** Commands which need to be installed in advance. */
  get $needs () {
    return {}
  }
}

if (!module.parent) {
  // Execute this file as apeman bin.
  require('apeman').cli(process.argv)
}
