/**
 * Test for inheritance.
 * Runs with mocha.
 */

'use strict'

const apeman = require('apeman')
const co = require('co')
const mkdirp = require('mkdirp')
const fs = require('fs')
const assert = require('assert')

describe('inherit', () => {
  let configuration = require.resolve('../doc/mocks/mock-Apemanfile.js')
  let { $cwd } = require(configuration)

  before(() => co(function * () {
    mkdirp.sync($cwd)
  }))

  before(() => co(function * () {
    fs.writeFile($cwd + '/package.json', "{}")
  }))

  before(() => co(function * () {
    fs.writeFile($cwd + '/Apemanfile.js', "module.exports={'$ctx':{env:()=>({})}}")
  }))

  before(() => co(function * () {
    fs.writeFile($cwd + '/env.js', "module.exports = function(){return {}}")
  }))

  it('Show tmpls.', () => co(function * () {
    yield apeman.show('tmpls', {
      configuration,
      keysonly: true
    })
  }))

  it('Show tasks.', () => co(function * () {
    yield apeman.show('tasks', {
      configuration,
      keysonly: true
    })
  }))

  it('Apply tmpls.', () => co(function * () {
    yield apeman.tmpl({
      force: true,
      configuration
    })
  }))

  it('Run mkdir tasks.', () => co(function * () {
    yield apeman.task('lemn:mkdir', {
      configuration
    })
  }))

  it('Run render tasks.', () => co(function * () {
    yield apeman.task('lemn:render', {
      configuration
    })
  }))

  it('Run chmod tasks.', () => co(function * () {
    yield apeman.task('lemn:chmod', {
      configuration
    })
  }))
})

/* global describe, before, after, it */
